import unittest
import data
from shady_tr import ShadyTextRandomizer


class ShadyTextRandomizerTest(unittest.TestCase):
    """Test ``shady_tr.shady_text_randomizer``."""

    def setUp(self):
        """Set up."""
        self.latin_text = data.latin_text
        self.cyrillic_text = data.cyrillic_text

    def test_01_randomize_cyrillic_chance_100(self):
        """Test randomize cyrillic text."""
        text_rnd = ShadyTextRandomizer(self.cyrillic_text, 100)
        result = text_rnd.random_cyrillic()
        self.assertNotEqual(result, self.cyrillic_text)
        return result

    def test_02_randomize_cyrillic_chance_0(self):
        """Test randomize cyrillic text."""
        text_rnd = ShadyTextRandomizer(self.cyrillic_text, 0)
        result = text_rnd.random_cyrillic()
        self.assertEqual(result, self.cyrillic_text)
        return result

    def test_03_randomize_latin_chance_100(self):
        """Test randomize cyrillic text."""
        text_rnd = ShadyTextRandomizer(self.latin_text, 100)
        result = text_rnd.random_latin()
        self.assertNotEqual(result, self.latin_text)
        return result

    def test_04_randomize_latin_chance_0(self):
        """Test randomize cyrillic text."""
        text_rnd = ShadyTextRandomizer(self.latin_text, 0)
        result = text_rnd.random_latin()
        self.assertEqual(result, self.latin_text)
        return result



import random
from .mapping import DICT_CYRILLIC
from .mapping import DICT_LATIN


class ShadyTextRandomizer:
    src_text = None
    chance = None

    def __init__(self, text, chance):
        self.src_text = list(text)
        self.chance = chance

    def random_cyrillic(self):
        return self.__randomize(DICT_CYRILLIC)

    def random_latin(self):
        return self.__randomize(DICT_LATIN)

    def __randomize(self, dictionary):
        text = self.src_text[:]
        i = 0
        for s in text:
            if s in dictionary:
                if random.randrange(1, 100) <= self.chance:
                    text[i] = random.choice(dictionary[s])
            i += 1
        return ''.join(text)



import os
import setuptools

with open(os.path.join(os.path.dirname(__file__), "README.md")) as readme:
    README = readme.read()

setuptools.setup(
    name="shady_tr",
    version="0.0.1",
    author="Ka3u6y6a",
    author_email="",
    description="Helps to avoid spam-filters by replacing some characters in text with similar characters from other languages",
    long_description=README,
    long_description_content_type="text/markdown",
    license='MIT License',
    url="https://github.com/Ka3u6y6a/shady_text_randomizer",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(exclude=["tests"]),
    keywords='text randomizer random',
    python_requires='>=3.6',
)
